@@ -1,5 +1,6 @@
 package Statistics::R::REXP::Character;
-
+# ABSTRACT: an R character vector
+$Statistics::R::REXP::Character::VERSION = '0.041';
 use 5.012;
 
 use Scalar::Util qw(looks_like_number);
@@ -21,15 +22,19 @@ sub _type { 'character'; }
 
 1; # End of Statistics::R::REXP::Character
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Statistics::R::REXP::Character - an R character vector
 
-
 =head1 VERSION
 
-This documentation refers to version 0.04 of the module.
-
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -40,13 +45,11 @@ This documentation refers to version 0.04 of the module.
     ]);
     print $vec->elements;
 
-
 =head1 DESCRIPTION
 
 An object of this class represents an R character vector
 (C<STRSXP>).
 
-
 =head1 METHODS
 
 C<Statistics::R::REXP:Character> inherits from
@@ -55,7 +58,6 @@ elements are scalar values. Elements that are not scalars (i.e.,
 numbers or strings) have value C<undef>, as do elements with R value
 C<NA>.
 
-
 =head1 BUGS AND LIMITATIONS
 
 Classes in the C<REXP> hierarchy are intended to be immutable. Please
@@ -64,21 +66,20 @@ do not try to change their value or attributes.
 There are no known bugs in this module. Please see
 L<Statistics::R::IO> for bug reporting.
 
-
 =head1 SUPPORT
 
 See L<Statistics::R::IO> for support and contact information.
 
-
 =head1 AUTHOR
 
-Davor Cubranic, C<< <cubranic at stat.ubc.ca> >>
+Davor Cubranic <cubranic@stat.ubc.ca>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE AND COPYRIGHT
+This software is Copyright (c) 2014 by University of British Columbia.
 
-Copyright 2014 University of British Columbia.
+This is free software, licensed under:
 
-See L<Statistics::R::IO> for the license.
+  The GNU General Public License, Version 3, June 2007
 
 =cut
