@@ -1,5 +1,6 @@
 package Statistics::R::REXP::Environment;
-
+# ABSTRACT: an R environment
+$Statistics::R::REXP::Environment::VERSION = '0.041';
 use 5.012;
 
 use Scalar::Util qw(refaddr blessed);
@@ -84,15 +85,19 @@ sub to_pl {
 
 1; # End of Statistics::R::REXP::Environment
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Statistics::R::REXP::Environment - an R environment
 
-
 =head1 VERSION
 
-This documentation refers to version 0.04 of the module.
-
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -104,7 +109,6 @@ This documentation refers to version 0.04 of the module.
     });
     print $env->elements;
 
-
 =head1 DESCRIPTION
 
 An object of this class represents an R environment (C<ENVSXP>).
@@ -124,7 +128,6 @@ will not have a defined 'names' attribute.
 You shouldn't create instances of this class, it exists mainly to
 handle deserialization of C<ENVSXP>s by the C<IO> classes.
 
-
 =head1 METHODS
 
 C<Statistics::R::REXP:Environment> inherits from
@@ -160,6 +163,7 @@ call this access will raise an exception.
 
 =back
 
+=for Pod::Coverage BUILDARGS
 
 =head1 BUGS AND LIMITATIONS
 
@@ -169,21 +173,20 @@ do not try to change their value or attributes.
 There are no known bugs in this module. Please see
 L<Statistics::R::IO> for bug reporting.
 
-
 =head1 SUPPORT
 
 See L<Statistics::R::IO> for support and contact information.
 
-
 =head1 AUTHOR
 
-Davor Cubranic, C<< <cubranic at stat.ubc.ca> >>
+Davor Cubranic <cubranic@stat.ubc.ca>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE AND COPYRIGHT
+This software is Copyright (c) 2014 by University of British Columbia.
 
-Copyright 2014 University of British Columbia.
+This is free software, licensed under:
 
-See L<Statistics::R::IO> for the license.
+  The GNU General Public License, Version 3, June 2007
 
 =cut
