@@ -1,5 +1,6 @@
 package Statistics::R::REXP::Language;
-
+# ABSTRACT: an R language vector
+$Statistics::R::REXP::Language::VERSION = '0.041';
 use 5.012;
 
 use Scalar::Util qw(blessed);
@@ -24,15 +25,19 @@ around _type => sub { 'language' };
 
 1; # End of Statistics::R::REXP::Language
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Statistics::R::REXP::Language - an R language vector
 
-
 =head1 VERSION
 
-This documentation refers to version 0.04 of the module.
-
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -45,7 +50,6 @@ This documentation refers to version 0.04 of the module.
     ]);
     print $vec->elements;
 
-
 =head1 DESCRIPTION
 
 An object of this class represents an R language vector (C<LANGSXP>).
@@ -57,7 +61,6 @@ L<Statistics::R::REXP::Character> vector), with unnamed arguments
 having name C<''>. If no arguments were named, the language objects
 will not have a defined 'names' attribute.
 
-
 =head1 METHODS
 
 C<Statistics::R::REXP:Language> inherits from
@@ -66,7 +69,6 @@ first element has to be a L<Statistics::R::REXP::Symbol> or another
 C<Language> instance. Trying to create a Language instance that
 doesn't follow this restriction will raise an exception.
 
-
 =head1 BUGS AND LIMITATIONS
 
 Classes in the C<REXP> hierarchy are intended to be immutable. Please
@@ -75,21 +77,20 @@ do not try to change their value or attributes.
 There are no known bugs in this module. Please see
 L<Statistics::R::IO> for bug reporting.
 
-
 =head1 SUPPORT
 
 See L<Statistics::R::IO> for support and contact information.
 
-
 =head1 AUTHOR
 
-Davor Cubranic, C<< <cubranic at stat.ubc.ca> >>
+Davor Cubranic <cubranic@stat.ubc.ca>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE AND COPYRIGHT
+This software is Copyright (c) 2014 by University of British Columbia.
 
-Copyright 2014 University of British Columbia.
+This is free software, licensed under:
 
-See L<Statistics::R::IO> for the license.
+  The GNU General Public License, Version 3, June 2007
 
 =cut
