@@ -1,5 +1,6 @@
 package Statistics::R::REXP::Logical;
-
+# ABSTRACT: an R logical vector
+$Statistics::R::REXP::Logical::VERSION = '0.041';
 use 5.012;
 
 use Moo;
@@ -19,15 +20,19 @@ sub _type { 'logical'; }
 
 1; # End of Statistics::R::REXP::Logical
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Statistics::R::REXP::Logical - an R logical vector
 
-
 =head1 VERSION
 
-This documentation refers to version 0.04 of the module.
-
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -38,13 +43,11 @@ This documentation refers to version 0.04 of the module.
     ]);
     print $vec->elements;
 
-
 =head1 DESCRIPTION
 
 An object of this class represents an R logical vector
 (C<LGLSXP>).
 
-
 =head1 METHODS
 
 C<Statistics::R::REXP:Logical> inherits from
@@ -53,7 +56,6 @@ elements are boolean (true/false) values. Elements have value 1 or 0,
 corresponding to C<TRUE> and C<FALSE>, respectively, while missing
 values (C<NA> in R) have value C<undef>.
 
-
 =head1 BUGS AND LIMITATIONS
 
 Classes in the C<REXP> hierarchy are intended to be immutable. Please
@@ -62,21 +64,20 @@ do not try to change their value or attributes.
 There are no known bugs in this module. Please see
 L<Statistics::R::IO> for bug reporting.
 
-
 =head1 SUPPORT
 
 See L<Statistics::R::IO> for support and contact information.
 
-
 =head1 AUTHOR
 
-Davor Cubranic, C<< <cubranic at stat.ubc.ca> >>
+Davor Cubranic <cubranic@stat.ubc.ca>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE AND COPYRIGHT
+This software is Copyright (c) 2014 by University of British Columbia.
 
-Copyright 2014 University of British Columbia.
+This is free software, licensed under:
 
-See L<Statistics::R::IO> for the license.
+  The GNU General Public License, Version 3, June 2007
 
 =cut
