@@ -1,5 +1,6 @@
 package Statistics::R::REXP::Vector;
-
+# ABSTRACT: an R vector
+$Statistics::R::REXP::Vector::VERSION = '0.041';
 use 5.012;
 
 use Scalar::Util qw(blessed);
@@ -92,15 +93,19 @@ sub to_pl {
 
 1; # End of Statistics::R::REXP::Vector
 
+__END__
+
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Statistics::R::REXP::Vector - an R vector
 
-
 =head1 VERSION
 
-This documentation refers to version 0.04 of the module.
-
+version 0.041
 
 =head1 SYNOPSIS
 
@@ -110,7 +115,6 @@ This documentation refers to version 0.04 of the module.
     $vec->does('Statistics::R::REXP::Vector');
     print $vec->elements;
 
-
 =head1 DESCRIPTION
 
 An object of this class represents an R vector. This class
@@ -118,7 +122,6 @@ cannot be directly instantiated (it's a L<Moo::Role>), because it is
 intended as a base abstract class with concrete subclasses to
 represent specific types of vectors, such as numeric or list.
 
-
 =head1 METHODS
 
 C<Statistics::R::REXP::Vector> inherits from L<Statistics::R::REXP>.
@@ -139,6 +142,7 @@ $vec->elements>.
 
 =back
 
+=for Pod::Coverage BUILDARGS is_vector
 
 =head1 BUGS AND LIMITATIONS
 
@@ -148,21 +152,20 @@ do not try to change their value or attributes.
 There are no known bugs in this module. Please see
 L<Statistics::R::IO> for bug reporting.
 
-
 =head1 SUPPORT
 
 See L<Statistics::R::IO> for support and contact information.
 
-
 =head1 AUTHOR
 
-Davor Cubranic, C<< <cubranic at stat.ubc.ca> >>
+Davor Cubranic <cubranic@stat.ubc.ca>
 
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE AND COPYRIGHT
+This software is Copyright (c) 2014 by University of British Columbia.
 
-Copyright 2014 University of British Columbia.
+This is free software, licensed under:
 
-See L<Statistics::R::IO> for the license.
+  The GNU General Public License, Version 3, June 2007
 
 =cut
